$wnd.rstudio.runAsyncCallback16("function iJk(a){this.a=a}\nfunction HHk(a,b){this.a=a;this.b=b;kse.call(this)}\nfunction kHk(a,b){a.a=b;xIk(a.p,gHk(a,null),a.a.file_path)}\nfunction mHk(a,b){b.slide_index==0&&NVi(a.p);a.a=b;xIk(a.p,gHk(a,null),a.a.file_path)}\nfunction sHk(a){rpf('Opening Presentation...',YEd());ZIf(a.c,new UKf,false)}\nfunction hHk(a){var b;b=$_f(new __f(0,'Closing Presentation...'));A$h(a.n,new HHk(a,b))}\nfunction A$h(a,b){y3h(a,Wpo,'close_presentation_pane',new PH,b)}\nfunction rHk(a){var b;a.J.BI();!!a.a&&a.a.active&&(b=kpe(Oh(a.p.d).contentWindow),!(!YRd(qTn,b)&&!YRd('javascript:void(0)',b)))&&kHk(a,a.a)}\nfunction eJk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=UJk(a.a.b.a);qQi(a.a,a.a.a)}switch(a.c){case 1:hHk((c=a.a.a,a.b[0],c));break;case 2:mHk(a.a.a,a.b[0]);break;case 3:a.a.a.J.zI();break;case 4:a.a.a.J.AI();break;case 5:rHk(a.a.a);break;case 6:sHk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nD6c(7034,32,{},HHk);_.kv=function JHk(a){var b;ZIf((b=this,a,b).a.c,new UKf,false)};_.jv=function IHk(a){q_f(this.b,a.a?a.a.c:a.d)};var poc=mQd(7034);D6c(461,1,eio);_.en=function hJk(){eJk((new iJk(this)).a)};D6c(6539,1,HSn,iJk);_.gn=function jJk(){eJk(this.a)};var Ooc=mQd(6539);uJn(hm)(16);\n//# sourceURL=rstudio-16.js\n")
